JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
fixed the border issue for mplayer, ff is definately broken when using F11 (fullscree...
[dwm.git] / layout.c
index c4727f0..6eae290 100644 (file)
--- a/layout.c
+++ b/layout.c
@@ -1,6 +1,6 @@
-/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
- * See LICENSE file for license details.
- */
+/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
+ * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
+ * See LICENSE file for license details. */
 #include "dwm.h"
 #include <stdlib.h>
 
@@ -38,18 +38,18 @@ tile(void) {
                        ny = way;
                        if(i < nmaster) {
                                ny += i * mh;
-                               nw = mw - 2 * BORDERPX;
-                               nh = mh - 2 * BORDERPX;
+                               nw = mw - 2 * c->border;
+                               nh = mh - 2 * c->border;
                        }
                        else {  /* tile window */
                                nx += mw;
-                               nw = tw - 2 * BORDERPX;
-                               if(th > 2 * BORDERPX) {
+                               nw = tw - 2 * c->border;
+                               if(th > 2 * c->border) {
                                        ny += (i - nmaster) * th;
-                                       nh = th - 2 * BORDERPX;
+                                       nh = th - 2 * c->border;
                                }
-                               else /* fallback if th <= 2 * BORDERPX */
-                                       nh = wah - 2 * BORDERPX;
+                               else /* fallback if th <= 2 * c->border */
+                                       nh = wah - 2 * c->border;
                        }
                        resize(c, nx, ny, nw, nh, False);
                        i++;
@@ -125,7 +125,7 @@ incmasterw(const char *arg) {
                masterw = MASTERWIDTH;
        else {
                i = atoi(arg);
-               if(waw * (masterw + i) / 1000 >= waw - 2 * BORDERPX
+               if(waw * (masterw + i) / 1000 >= waw - 2 * BORDERPX 
                || waw * (masterw + i) / 1000 <= 2 * BORDERPX)
                        return;
                masterw += i;